@@ -94,11 +94,11 @@ class TestAstimezone(object):
         assert astimezone(None) is None
 
     def test_bad_timezone_type(self):
-        exc = pytest.raises(TypeError, astimezone, tzinfo())
-        assert 'Only timezones from the pytz library are supported' in str(exc.value)
+        pytest.raises(NotImplementedError, astimezone, tzinfo()).\
+            match(r'(a )?tzinfo subclass must (implement|override) tzname\(\)')
 
     def test_bad_local_timezone(self):
-        zone = Mock(tzinfo, localize=None, normalize=None, zone='local')
+        zone = Mock(tzinfo, localize=None, normalize=None, tzname=lambda dt: 'local')
         exc = pytest.raises(ValueError, astimezone, zone)
         assert 'Unable to determine the name of the local timezone' in str(exc.value)
 
@@ -148,11 +148,6 @@ class TestConvertToDatetime(object):
         returned = convert_to_datetime('2009-8-1', 'UTC', None)
         assert returned == datetime(2009, 8, 1, tzinfo=pytz.utc)
 
-    def test_bad_timezone(self):
-        exc = pytest.raises(TypeError, convert_to_datetime, '2009-8-1', tzinfo(), None)
-        assert str(exc.value) == ('Only pytz timezones are supported (need the localize() and '
-                                  'normalize() methods)')
-
 
 def test_datetime_to_utc_timestamp(timezone):
     dt = timezone.localize(datetime(2014, 3, 12, 5, 40, 13, 254012))
